Re: [cp-patches] Little XML patch

2007-04-09 Thread Christian Thalinger
On Sat, 2007-04-07 at 19:14 +0200, Mark Wielaard wrote:
 Hi Christian,
 
 On Sat, 2007-04-07 at 17:03 +0200, Christian Thalinger wrote:
  This patch broke SPECjbb2005
  (http://developer.classpath.org/pipermail/classpath/2007-March/001917.html).
 
 Could you provide us with the input (input.systemId, ids.systemId) and
 result (url) of the following in XMLParser.java at line 1543
   String url = absolutize(input.systemId, ids.systemId);
 before and after this patch with your program?
 
 That might help analyze the problem and why the patch breaks it.

Ok, here we go:

input.systemId=file:/home/twisti/cacao/spec/jbb2005/xml/template-document.xml
ids.systemId=jbb-document.dtd
url=jbb-document.dtd

These files are in:

$ ls -l xml/
total 8
-r--r--r-- 1 twisti twisti 481 Nov  2  2004 jbb-document.dtd
-r--r--r-- 1 twisti twisti 339 Oct 11  2004 template-document.xml

- twisti



Re: [cp-patches] Little XML patch

2007-04-09 Thread Christian Thalinger
On Mon, 2007-04-09 at 19:17 +0200, Christian Thalinger wrote:
 Ok, here we go:
 
 input.systemId=file:/home/twisti/cacao/spec/jbb2005/xml/template-document.xml
 ids.systemId=jbb-document.dtd
 url=jbb-document.dtd

This is the output before Chris' patch:

input.systemId=file:/home/twisti/cacao/spec/jbb2005/xml/template-document.xml
ids.systemId=file:/home/twisti/cacao/spec/jbb2005/xml/jbb-document.dtd
url=file:/home/twisti/cacao/spec/jbb2005/xml/jbb-document.dtd

- twisti



[cp-patches] [gjdoc] FYI: Add basic annotation support

2007-04-09 Thread Andrew John Hughes
I'm committing this on behalf of Stephan Michels
to add annotation support to gjdoc (it gets it a bit
further on classpath).
No more patches should be added without an assignment.

2007-04-09  Stephan Michels  [EMAIL PROTECTED]

* src/gnu/classpath/tools/gjdoc/ClassDocImpl.java,
* src/gnu/classpath/tools/gjdoc/Parser.java:
Add basic annotation support.
-- 
Andrew :-)

Escape the Java Trap with GNU Classpath!
http://www.gnu.org/philosophy/java-trap.html
public class gcj extends Freedom implements Java { ... }
Index: src/gnu/classpath/tools/gjdoc/ClassDocImpl.java
===
RCS file: /sources/classpath/gjdoc/src/gnu/classpath/tools/gjdoc/ClassDocImpl.java,v
retrieving revision 1.28
diff -u -3 -p -u -r1.28 ClassDocImpl.java
--- src/gnu/classpath/tools/gjdoc/ClassDocImpl.java	27 Oct 2005 13:33:21 -	1.28
+++ src/gnu/classpath/tools/gjdoc/ClassDocImpl.java	9 Apr 2007 18:17:42 -
@@ -200,6 +200,10 @@ public class ClassDocImpl
   return isInterface;
}
 
+   public boolean isAnnotation() {
+  return isAnnotation;
+   }
+
// Return true if this class is abstract 
public void setIsAbstract(boolean b) {
   this.isAbstract=b;
@@ -316,9 +320,11 @@ public class ClassDocImpl
   final int STATE_NORMAL = 1;
   final int STATE_SLASHC = 2;
   final int STATE_STARC  = 3;
+  final int STATE_ANNO   = 4;
 
   int state=STATE_NORMAL;
   int varLevel=0;
+  int parLevel=0;
   char prev=0;
   for (int ndx=startIndex; ndx=endIndex; ++ndx) {
 	 char c=(ndx==endIndex)?10:source[ndx];
@@ -348,6 +354,20 @@ public class ClassDocImpl
 	   word=word.substring(0,word.length()-1);
 	   processWord=true;
 	}
+	else if (c=='@') {
+   state=STATE_ANNO;
+	   word += c;
+	}
+	else if (c=='('  state==STATE_ANNO) {
+   ++parLevel;
+   word += c;
+}
+else if (c==')'  state==STATE_ANNO) {
+   --parLevel;
+   word += c;
+	   if (parLevel == 0)
+   state=STATE_NORMAL;
+}
 	else if (c=='')
 	  {
 		++varLevel;
@@ -358,9 +378,11 @@ public class ClassDocImpl
 		--varLevel;
 		word += c;
 	  }
-	else if (c=='{' || c==','  varLevel == 0 || 
-		 Parser.WHITESPACE.indexOf(c)=0) {
+	else if (c=='{'  parLevel == 0 || 
+	 c==','  varLevel == 0  parLevel == 0 || 
+		 Parser.WHITESPACE.indexOf(c)=0  parLevel == 0 ) {
 	   processWord=true;
+	   state=STATE_NORMAL;
 	}
 	else {
 	   word+=c;
@@ -381,13 +403,18 @@ public class ClassDocImpl
 		 rc.setIsInterface(true);
 		 item=1;
 		  }
+		  else if (word.equals(@interface)) {
+		 rc.setIsInterface(true);
+ rc.setIsAnnotation(true);
+		 item=1;
+		  }
 		  else if (word.equals(strictfp)) {
 		  }
 		  else {
 		 Main.getRootDoc().printWarning(unknown modifier '+word+');
 		  }
 	   }
-	   else if (word.equals(extends)) {
+	   else if (word.equals(extends)  !rc.isAnnotation()) {
   if (rc.isInterface()) {
  item=3;
   }
@@ -395,7 +422,7 @@ public class ClassDocImpl
  item=2;
   }
 	   }
-	   else if (word.equals(implements)) {
+	   else if (word.equals(implements)  !rc.isAnnotation()) {
 		  item=3;
 	   }
 	   else if (item==1) {
@@ -433,7 +460,7 @@ public class ClassDocImpl
 	   word=;
 	}
 
-	if (c=='{') break;
+	if (c=='{'  state==STATE_NORMAL) break;
 	 }
 	 prev=c;
   }
@@ -697,6 +724,7 @@ public class ClassDocImpl
 
private boolean isAbstract;
private boolean isInterface;
+   private boolean isAnnotation;
private ClassDoc[] interfaces;
private ClassDoc[] filteredInnerClasses;
private ClassDoc[] unfilteredInnerClasses;
@@ -826,6 +854,10 @@ public class ClassDocImpl
   this.isInterface=b;
}
 
+   public void setIsAnnotation(boolean b) {
+  this.isAnnotation=b;
+   }
+
public ExecutableMemberDoc findExecutableRec(String nameAndSignature) {
 
   ExecutableMemberDoc rc;
Index: src/gnu/classpath/tools/gjdoc/Parser.java
===
RCS file: /sources/classpath/gjdoc/src/gnu/classpath/tools/gjdoc/Parser.java,v
retrieving revision 1.25
diff -u -3 -p -u -r1.25 Parser.java
--- src/gnu/classpath/tools/gjdoc/Parser.java	1 Jul 2005 18:38:43 -	1.25
+++ src/gnu/classpath/tools/gjdoc/Parser.java	9 Apr 2007 18:17:42 -
@@ -541,6 +541,25 @@ import gnu.classpath.tools.MalformedInpu
   }
}
break;
+case '@':  // annotation
+   index += 1;
+   while(indexsource.length   Character.isJavaIdentifierPart(source[index])) {
+   ++ index;
+   }
+   if (indexsource.length  source[index]=='(') {
+	

[cp-patches] FYI: Add 1.6 ObjectName methods

2007-04-09 Thread Andrew John Hughes
This patch adds the missing 1.6 methods to ObjectName.
Now we just need to be able to apply the new patterns...

Changelog:

2007-04-07  Andrew John Hughes  [EMAIL PROTECTED]

* javax/management/ObjectName.java:
(propertyValuePattern): New cache variable.
(parse(String)): Record in propertyListPattern
not propertyPattern and set propertyValuePattern.
(isPropertyPattern()): Semantics altered to be the
OR of isPropertyListPattern() and isPropertyValuePattern().
(isPropertyListPattern()): Implemented.
(isPropertyValuePattern()): Implemented.
(isPropertyValuePattern(String)): Implemented.

Index: native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c
===
RCS file: /cvsroot/classpath/classpath/native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c,v
retrieving revision 1.18
diff -u -r1.18 gnu_java_awt_peer_gtk_ComponentGraphics.c
--- native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c	3 Aug 2006 08:08:14 -	1.18
+++ native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c	9 Apr 2007 21:23:04 -
@@ -159,40 +159,13 @@
 
   cr = cairo_create (surface);
   g_assert(cr != NULL);
+  cairo_surface_destroy(surface);
 
   gdk_threads_leave();
 
   return PTR_TO_JLONG(cr);
 }
 
-/**
- * Disposes of the surface
- */
-JNIEXPORT void JNICALL
-Java_gnu_java_awt_peer_gtk_ComponentGraphics_disposeSurface
-  (JNIEnv *env __attribute__((unused)), jobject obj __attribute__((unused)),
-   jlong value)
-{
-  struct cairographics2d *gr;
-  cairo_surface_t *surface;
-
-  gr = JLONG_TO_PTR(struct cairographics2d, value);
-
-  if (gr == NULL)
-return;
-
-  if (gr-cr == NULL)
-return;
-
-  surface = cairo_get_target (gr-cr);
-  if (surface != NULL)
-{
-  gdk_threads_enter();
-  cairo_surface_destroy (surface);
-  gdk_threads_leave();
-}
-}
-
 JNIEXPORT jlong JNICALL 
 Java_gnu_java_awt_peer_gtk_ComponentGraphics_initFromVolatile
   (JNIEnv *env  __attribute__ ((unused)), jobject obj __attribute__ ((unused)),
Index: gnu/java/awt/peer/gtk/ComponentGraphics.java
===
RCS file: /cvsroot/classpath/classpath/gnu/java/awt/peer/gtk/ComponentGraphics.java,v
retrieving revision 1.27
diff -u -r1.27 ComponentGraphics.java
--- gnu/java/awt/peer/gtk/ComponentGraphics.java	4 Apr 2007 19:20:33 -	1.27
+++ gnu/java/awt/peer/gtk/ComponentGraphics.java	9 Apr 2007 21:23:04 -
@@ -151,21 +151,6 @@
   }
 
   /**
-   * Destroys the component surface and calls dispose on the cairo
-   * graphics2d to destroy any super class resources.
-   */
-  public void dispose()
-  {
-super.dispose();
-disposeSurface(nativePointer);
-  }
-
-  /**
-   * Destroys the component surface.
-   */
-  private native void disposeSurface(long nativePointer);
-
-  /**
* Creates a cairo_t for a volatile image
*/
   protected native long initFromVolatile( long pixmapPtr, int width, int height);
Index: include/gnu_java_awt_peer_gtk_ComponentGraphics.h
===
RCS file: /cvsroot/classpath/classpath/include/gnu_java_awt_peer_gtk_ComponentGraphics.h,v
retrieving revision 1.10
diff -u -r1.10 gnu_java_awt_peer_gtk_ComponentGraphics.h
--- include/gnu_java_awt_peer_gtk_ComponentGraphics.h	21 Aug 2006 23:34:45 -	1.10
+++ include/gnu_java_awt_peer_gtk_ComponentGraphics.h	9 Apr 2007 21:23:04 -
@@ -11,7 +11,6 @@
 #endif
 
 JNIEXPORT jlong JNICALL Java_gnu_java_awt_peer_gtk_ComponentGraphics_initState (JNIEnv *env, jobject, jobject);
-JNIEXPORT void JNICALL Java_gnu_java_awt_peer_gtk_ComponentGraphics_disposeSurface (JNIEnv *env, jobject, jlong);
 JNIEXPORT jlong JNICALL Java_gnu_java_awt_peer_gtk_ComponentGraphics_initFromVolatile (JNIEnv *env, jobject, jlong, jint, jint);
 JNIEXPORT void JNICALL Java_gnu_java_awt_peer_gtk_ComponentGraphics_start_1gdk_1drawing (JNIEnv *env, jobject);
 JNIEXPORT void JNICALL Java_gnu_java_awt_peer_gtk_ComponentGraphics_end_1gdk_1drawing (JNIEnv *env, jobject);


[cp-patches] FYI: Fix ObjectName bugs

2007-04-09 Thread Andrew John Hughes
This fixes bugs in our parsing in javax.management.ObjectName
so that we pass all the tests recently committed to Mauve
for parsing.

Mark, please add to the release.

Changelog:

2007-04-09  Andrew John Hughes  [EMAIL PROTECTED]

* javax/management/ObjectName.java:
(parse(String)): Catch multiple wildcards,
initialise with an empty string (so null isn't
appended), and emit comma even when wildcard
ends the list.
(checkComponents()): Catch newlines.
(quote(String)): Handle newlines and quotes
correctly.

-- 
Andrew :-)

Escape the Java Trap with GNU Classpath!
http://www.gnu.org/philosophy/java-trap.html
public class gcj extends Freedom implements Java { ... }
Index: javax/management/ObjectName.java
===
RCS file: /cvsroot/classpath/classpath/javax/management/ObjectName.java,v
retrieving revision 1.15
diff -u -3 -p -u -r1.15 ObjectName.java
--- javax/management/ObjectName.java	9 Apr 2007 18:25:42 -	1.15
+++ javax/management/ObjectName.java	9 Apr 2007 22:21:05 -
@@ -209,10 +209,14 @@ public class ObjectName
   throw new MalformedObjectNameException(A name that is not a  +
 	 pattern must contain at  +
 	 least one key-value pair.);
+propertyListString = ;
 for (int a = 0; a  pairs.length; ++a)
   {
 	if (pairs[a].equals(*))
 	  {
+	if (propertyListPattern)
+	  throw new MalformedObjectNameException(Multiple wildcards  +
+		 in properties.);
 	propertyListPattern = true;
 	continue;
 	  }
@@ -226,10 +230,11 @@ public class ObjectName
 		 more than once.);
 	String value = pairs[a].substring(sep+1);
 	properties.put(key, value);
-	propertyListString += key + = + value;
-	if (a != (pairs.length - 1))
-	  propertyListString += ,;
+	propertyListString += key + = + value + ,;
   }
+if (propertyListString.length()  0)
+  propertyListString =
+	propertyListString.substring(0, propertyListString.length() - 1);
 checkComponents();
   }
 
@@ -298,8 +303,8 @@ public class ObjectName
 if (domain.indexOf('\n') != -1)
   throw new MalformedObjectNameException(The domain includes a newline  +
 	 character.);
-char[] keychars = new char[] { ':', ',', '*', '?', '=' };
-char[] valchars = new char[] { ':', ',', '=' };
+char[] keychars = new char[] { '\n', ':', ',', '*', '?', '=' };
+char[] valchars = new char[] { '\n', ':', ',', '=' };
 Iterator i = properties.entrySet().iterator();
 while (i.hasNext())
   {
@@ -320,8 +325,9 @@ public class ObjectName
 	  }
 	catch (IllegalArgumentException e)
 	  {
-		throw new MalformedObjectNameException(The quoted value is  +
-		   invalid.);
+		throw (MalformedObjectNameException)
+		  new MalformedObjectNameException(The quoted value is  +
+		   invalid.).initCause(e);
 	  }
 	  }
 	else if (quote != -1)
@@ -927,10 +933,12 @@ public class ObjectName
 	  {
 	n = q.charAt(++a);
 	if (n != ''  n != '?'  n != '*' 
-		n != '\n'  n != '\\')
+		n != 'n'  n != '\\')
 	  throw new IllegalArgumentException(Illegal escaped character: 
 		 + n);
 	  }
+	else if (n == '' || n == '\n') 
+	  throw new IllegalArgumentException(Illegal character:  + n);
 	builder.append(n);
   }
 


signature.asc
Description: Digital signature


[cp-patches] [gjdoc] FYI: Add enum support and fix type variable bug

2007-04-09 Thread Andrew John Hughes
This gets us a stage further with gjdoc,
allowing it to parse enums and handle type
variables that contain whitespace.  It currently
runs out of memory before completing a run of Classpath.

Changelog:

2007-04-10  Andrew John Hughes  [EMAIL PROTECTED]

* src/gnu/classpath/tools/gjdoc/ClassDocImpl.java:
Add enumeration support and allow whitespace in
type variables.
* src/gnu/classpath/tools/gjdoc/Parser.java:
Add commented-out line for printing file being
processed.

-- 
Andrew :-)

Escape the Java Trap with GNU Classpath!
http://www.gnu.org/philosophy/java-trap.html
public class gcj extends Freedom implements Java { ... }
Index: src/gnu/classpath/tools/gjdoc/ClassDocImpl.java
===
RCS file: /sources/classpath/gjdoc/src/gnu/classpath/tools/gjdoc/ClassDocImpl.java,v
retrieving revision 1.29
diff -u -3 -p -u -r1.29 ClassDocImpl.java
--- src/gnu/classpath/tools/gjdoc/ClassDocImpl.java	9 Apr 2007 18:31:32 -	1.29
+++ src/gnu/classpath/tools/gjdoc/ClassDocImpl.java	9 Apr 2007 23:42:10 -
@@ -204,6 +204,11 @@ public class ClassDocImpl
   return isAnnotation;
}
 
+  public boolean isEnum()
+  {
+return isEnum;
+  }
+
// Return true if this class is abstract 
public void setIsAbstract(boolean b) {
   this.isAbstract=b;
@@ -380,7 +385,7 @@ public class ClassDocImpl
 	  }
 	else if (c=='{'  parLevel == 0 || 
 	 c==','  varLevel == 0  parLevel == 0 || 
-		 Parser.WHITESPACE.indexOf(c)=0  parLevel == 0 ) {
+		 Parser.WHITESPACE.indexOf(c)=0  parLevel == 0  varLevel == 0) {
 	   processWord=true;
 	   state=STATE_NORMAL;
 	}
@@ -399,6 +404,11 @@ public class ClassDocImpl
 		 rc.setIsInterface(false);
 		 item=1;
 		  }
+		  else if (word.equals(enum)) 
+		{
+		  rc.setIsEnum(true);
+		  item = 1;
+		}
 		  else if (word.equals(interface)) {
 		 rc.setIsInterface(true);
 		 item=1;
@@ -725,6 +735,7 @@ public class ClassDocImpl
private boolean isAbstract;
private boolean isInterface;
private boolean isAnnotation;
+   private boolean isEnum;
private ClassDoc[] interfaces;
private ClassDoc[] filteredInnerClasses;
private ClassDoc[] unfilteredInnerClasses;
@@ -858,6 +869,11 @@ public class ClassDocImpl
   this.isAnnotation=b;
}
 
+   public void setIsEnum(boolean b)
+   {
+ isEnum = b;
+   }
+
public ExecutableMemberDoc findExecutableRec(String nameAndSignature) {
 
   ExecutableMemberDoc rc;
Index: src/gnu/classpath/tools/gjdoc/Parser.java
===
RCS file: /sources/classpath/gjdoc/src/gnu/classpath/tools/gjdoc/Parser.java,v
retrieving revision 1.26
diff -u -3 -p -u -r1.26 Parser.java
--- src/gnu/classpath/tools/gjdoc/Parser.java	9 Apr 2007 18:31:32 -	1.26
+++ src/gnu/classpath/tools/gjdoc/Parser.java	9 Apr 2007 23:42:10 -
@@ -727,6 +727,7 @@ public class Parser {
   String encoding, String expectedPackageName) 
   throws IOException, ParseException
{
+ //System.err.println(Processing  + file + ...);
   this.currentFile = file;
   this.currentPackage = null;
   this.currentPackageName = null;


signature.asc
Description: Digital signature


[cp-testresults] FAIL: classpath build with ecj on Mon Apr 9 12:00:44 UTC 2007

2007-04-09 Thread cpdev
checking for iconv declaration... 
 extern size_t iconv (iconv_t cd, char * *inbuf, size_t *inbytesleft, 
char * *outbuf, size_t *outbytesleft);
checking for X... libraries , headers 
checking for gethostbyname... yes
checking for connect... (cached) yes
checking for remove... yes
checking for shmat... yes
checking for IceConnectionNumber in -lICE... yes
checking for XTestQueryExtension in -lXtst... yes
checking for pkg-config... /usr/bin/pkg-config
checking for gtk+-2.0 = 2.8 gthread-2.0 = 2.2 gdk-pixbuf-2.0... yes
checking GTK_CFLAGS... -pthread -I/usr/include/gtk-2.0 
-I/usr/lib/gtk-2.0/include -I/usr/include/atk-1.0 -I/usr/include/cairo 
-I/usr/include/pango-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include 
-I/usr/include/freetype2 -I/usr/include/libpng12  
checking GTK_LIBS... -pthread -lgtk-x11-2.0 -lgdk-x11-2.0 -latk-1.0 
-lpangocairo-1.0 -lfontconfig -lXext -lXrender -lXinerama -lXi -lXrandr 
-lXcursor -lXfixes -lpango-1.0 -lcairo -lX11 -lgthread-2.0 -lgdk_pixbuf-2.0 -lm 
-lgobject-2.0 -lgmodule-2.0 -ldl -lglib-2.0  
checking for freetype2... yes
checking FREETYPE2_CFLAGS... -I/usr/include/freetype2  
checking FREETYPE2_LIBS... -lfreetype -lz  
checking for pangoft2... yes
checking PANGOFT2_CFLAGS... -I/usr/include/pango-1.0 -I/usr/include/freetype2 
-I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include  
checking PANGOFT2_LIBS... -lpangoft2-1.0 -lpango-1.0 -lgobject-2.0 
-lgmodule-2.0 -ldl -lglib-2.0  
checking for XRenderQueryExtension in -lXrender... yes
checking for XRRQueryExtension in -lXrandr... yes
checking for gconf-2.0 = 2.6.0... yes
checking GCONF_CFLAGS... -DORBIT2=1 -pthread -I/usr/include/gconf/2 
-I/usr/include/orbit-2.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include  
checking GCONF_LIBS... -pthread -lgconf-2 -lORBit-2 -lm -lgmodule-2.0 -ldl 
-lgthread-2.0 -lglib-2.0  
checking for gdk-2.0 = 2.8... yes
checking GDK_CFLAGS... -I/usr/include/gtk-2.0 -I/usr/lib/gtk-2.0/include 
-I/usr/include/pango-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include 
-I/usr/include/cairo -I/usr/include/freetype2 -I/usr/include/libpng12  
checking GDK_LIBS... -lgdk-x11-2.0 -lgdk_pixbuf-2.0 -lm -lpangocairo-1.0 
-lfontconfig -lXext -lXrender -lXinerama -lXi -lXrandr -lXcursor -lXfixes 
-lpango-1.0 -lcairo -lgobject-2.0 -lgmodule-2.0 -ldl -lglib-2.0 -lX11  
checking for MSG_NOSIGNAL... yes
checking for SO_NOSIGPIPE ... no
checking for mozilla-plugin... checking for firefox-plugin firefox-xpcom... 
checking for xulrunner-plugin xulrunner-xpcom... checking for 
mozilla-firefox-plugin mozilla-firefox-xpcom... checking for seamonkey-plugin 
seamonkey-xpcom... configure: error: Couldn't find plugin support headers and 
libraries, try --disable-plugin


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: jamvm build on Mon Apr 9 12:01:35 UTC 2007

2007-04-09 Thread cpdev
Making all in sun
make[2]: Entering directory `/home/cpdev/Nightly/jamvm/build/lib/sun'
Making all in reflect
make[3]: Entering directory `/home/cpdev/Nightly/jamvm/build/lib/sun/reflect'
Making all in annotation
make[4]: Entering directory 
`/home/cpdev/Nightly/jamvm/build/lib/sun/reflect/annotation'
make[4]: Nothing to be done for `all'.
make[4]: Leaving directory 
`/home/cpdev/Nightly/jamvm/build/lib/sun/reflect/annotation'
make[4]: Entering directory `/home/cpdev/Nightly/jamvm/build/lib/sun/reflect'
make[4]: Nothing to be done for `all-am'.
make[4]: Leaving directory `/home/cpdev/Nightly/jamvm/build/lib/sun/reflect'
make[3]: Leaving directory `/home/cpdev/Nightly/jamvm/build/lib/sun/reflect'
make[3]: Entering directory `/home/cpdev/Nightly/jamvm/build/lib/sun'
make[3]: Nothing to be done for `all-am'.
make[3]: Leaving directory `/home/cpdev/Nightly/jamvm/build/lib/sun'
make[2]: Leaving directory `/home/cpdev/Nightly/jamvm/build/lib/sun'
make[2]: Entering directory `/home/cpdev/Nightly/jamvm/build/lib'
mkdir classes
ecj -bootclasspath 
/home/cpdev/Nightly/classpath/install/share/classpath/glibj.zip -d classes 
../../jamvm/lib/jamvm/java/lang/JarLauncher.java 
../../jamvm/lib/java/lang/VMRuntime.java 
../../jamvm/lib/java/lang/VMClassLoader.java 
../../jamvm/lib/java/lang/VMString.java ../../jamvm/lib/java/lang/VMThread.java 
../../jamvm/lib/java/lang/VMThrowable.java 
../../jamvm/lib/java/lang/reflect/Constructor.java 
../../jamvm/lib/java/lang/reflect/Field.java 
../../jamvm/lib/java/lang/reflect/Method.java 
../../jamvm/lib/java/security/VMAccessController.java 
../../jamvm/lib/gnu/classpath/VMSystemProperties.java 
../../jamvm/lib/sun/reflect/annotation/AnnotationInvocationHandler.java 
../../jamvm/lib/gnu/classpath/VMStackWalker.java
-- 
Andrew :-)

Escape the Java Trap with GNU Classpath!
http://www.gnu.org/philosophy/java-trap.html
public class gcj extends Freedom implements Java { ... }
Index: javax/management/ObjectName.java
===
RCS file: /cvsroot/classpath/classpath/javax/management/ObjectName.java,v
retrieving revision 1.14
diff -u -3 -p -u -r1.14 ObjectName.java
--- javax/management/ObjectName.java	7 Apr 2007 22:48:02 -	1.14
+++ javax/management/ObjectName.java	9 Apr 2007 13:23:43 -
@@ -71,7 +71,7 @@ import java.io.ObjectOutputStream;
  * is separated by commas, and largely consists of unordered key-value
  * pairs, separated by an equals sign ('=').  At most one element may
  * be an asterisk ('*'), which turns the [EMAIL PROTECTED] ObjectName} instance
  * into a emphproperty pattern/emph.  In this situation, the pattern
  * matches a name if the name contains at least those key-value pairs
  * given and has the same domain.
  * /p
@@ -89,6 +89,13 @@ import java.io.ObjectOutputStream;
  * (after expansion) are considered part of the value.
  * /p
  * p
+ * Both quoted and unquoted values may contain the wildcard characters
+ * '?' and '*'.  A name with at least one value containing a wildcard
+ * character is known as a emphproperty value pattern/emph.  A
+ * name is generally a emphproperty pattern/emph if it is either
+ * a emphproperty list pattern/emph or emphproperty value pattern/emph.
+ * /p
+ * p
  * Spaces are maintained within the different parts of the name.  Thus,
  * 'codedomain: key1 = value1 /code' has a key ' key1 ' with value
  * ' value1 '.  Newlines are disallowed, except where escaped in quoted
@@ -127,9 +134,14 @@ public class ObjectName
   private transient String propertyListString;
 
   /**
    * True if this object name is a property pattern.
*/
-  private transient boolean propertyPattern;
+  private transient boolean propertyListPattern;
+
+  /**
+   * True if this object name is a property value pattern.
+   */
+  private transient boolean propertyValuePattern;
 
   /**
* The management server associated with this object name.
@@ -201,7 +213,7 @@ public class ObjectName
   {
 	if (pairs[a].equals(*))
 	  {
-	propertyPattern = true;
+	propertyListPattern = true;
 	continue;
 	  }
 	int sep = pairs[a].indexOf('=');
@@ -322,7 +334,10 @@ public class ObjectName
 		throw new MalformedObjectNameException(A value contains  +
 		   a ' + valchars[a] + '  +
 		   character.);
+	
 	  }
+	if (value.indexOf('*') != -1 || value.indexOf('?') != -1)
+	  propertyValuePattern = true;
   }
   }
 
@@ -685,14 +700,60 @@ public class ObjectName
   }
 
   /**
    * Returns true if this object name is a property pattern.  This is
    * the case if the list of properties contains an '*'.
*
-   * @return true if this is a property pattern.
+   * @return true if the properties of this name contain a pattern.
+   * @see #isPropertyListPattern
+   * @see #isPropertyValuePattern
*/
   public boolean isPropertyPattern()
   {
-return propertyPattern;
+return propertyListPattern || propertyValuePattern;
+  }
+
+  /**
+   * Returns true if this object name is a property list pattern.  This is
+   * the case if the list of properties contains an '*'.
+   *
+   * @return true if this is a property list pattern.
+   * @since 1.6
+   */
+  public boolean isPropertyListPattern()
+  {
+return propertyListPattern;
+  }
+
+  /**
+   * Returns true if this object name is a property value pattern.  This is
+   * the case if one of the values contains a wildcard character,
+   * '?' or '*'.
+   *
+   * @return true if this is a property value pattern.
+   * @since 1.6
+   */
+  public boolean isPropertyValuePattern()
+  {
+return propertyValuePattern;
+  }
+
+  /**
+   * Returns true if the value of the given key is a pattern.  This is
+   * the case if the value contains a wildcard character, '?' or '*'.
+   *
+   * @param key the key whose value should be checked.
+   * @return true if the value of the given 
@@ -71,7 +71,7 @@ import java.io.ObjectOutputStream;
  * pairs, separated by an equals sign ('=').  At most one element may
  * be an asterisk ('*'), which turns the [EMAIL PROTECTED] ObjectName} instance
- * into a emphproperty pattern/emph.  In this situation, the pattern
+ * into a emphproperty list pattern/emph.  In this situation, the pattern
  * matches a name if the name contains at least those key-value pairs
  * given and has the same domain.
@@ -127,9 +134,14 @@ public class ObjectName
 
   /**
-   * True if this object name is a property pattern.
+   * True if this object name is a property list pattern.
*/
@@ -685,14 +700,60 @@ public class ObjectName
 
   /**
-   * Returns true if this object name is a property pattern.  This is
-   * the case if the list of properties contains an '*'.
+   * Returns true if this object name is a property list
+   * pattern, a property value pattern or both.
*

[cp-patches] FYI: Fix gtk memory leak hang

2007-04-09 Thread Francis Kung

Hi,

This patch fixes a memory leak in ComponentGraphics (used for drawing 
onto GTK surfaces).  Due to the ordering of dispose() methods, 
CairoGraphics2D.dispose was being called before 
ComponentGraphics.disposeSurface - thus disposeSurface returned 
prematurely before destroying the surface.  Rather than re-ordering the 
dispose calls, this patch destroys the surface immediately after it's 
used the initialize the cairo context (the cairo context will keep its 
own reference to the surface).


One of the rather nasty symptoms of this memory leak was a hanging X 
server once the application is exited.


Any chance for this to get in the upcoming release too? =)

Cheers,
Francis

2007-04-09  Francis Kung  [EMAIL PROTECTED]

PR 31311
* gnu/java/awt/peer/gtk/ComponentGraphics.java
(dispose): Removed method.
(disposeSurface): Removed method.
* gnu_java_awt_peer_gtk_ComponentGraphics.h: Regenerated.
* native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c
(Java_gnu_java_awt_peer_gtk_ComponentGraphics_disposeSurface): Removed.
(Java_gnu_java_awt_peer_gtk_ComponentGraphics_initState): Destroy 
surface
after it is used to create a cairo context.
--
1. ERROR in ../../jamvm/lib/jamvm/java/lang/JarLauncher.java (at line 1)
/*
^
The type java.lang.Object cannot be resolved. It is indirectly referenced from 
required .class files
--
1 problem (1 error)make[2]: *** [classes.zip] Error 255
make[2]: Leaving directory `/home/cpdev/Nightly/jamvm/build/lib'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/home/cpdev/Nightly/jamvm/build/lib'
make: *** [all-recursive] Error 1


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: cacao build on Mon Apr 9 12:02:22 UTC 2007

2007-04-09 Thread cpdev
checking for dlopen in -ldl... yes
checking whether a program can dlopen itself... yes
checking whether a statically linked program can dlopen itself... no
checking if libtool supports shared libraries... yes
checking whether to build shared libraries... yes
checking whether to build static libraries... no
configure: creating libtool
appending configuration tag CXX to libtool
checking for ld used by g++... /usr/bin/ld
checking if the linker (/usr/bin/ld) is GNU ld... yes
checking whether the g++ linker (/usr/bin/ld) supports shared libraries... yes
checking for g++ option to produce PIC... -fPIC
checking if g++ PIC flag -fPIC works... yes
checking if g++ static flag -static works... yes
checking if g++ supports -c -o file.o... yes
checking whether the g++ linker (/usr/bin/ld) supports shared libraries... yes
checking dynamic linker characteristics... GNU/Linux ld.so
checking how to hardcode library paths into programs... immediate
appending configuration tag F77 to libtool
checking whether to link CACAO statically... no
checking where CACAO's vm.zip is installed... 
/home/cpdev/Nightly/cacao/install/share/cacao/vm.zip
checking which Java core library to use... gnu
checking where Java core library is installed... 
/home/cpdev/Nightly/classpath/install
checking where Java core library classes are installed... 
/home/cpdev/Nightly/classpath/install/share/classpath/glibj.zip
checking where Java core library native libraries are installed... 
/home/cpdev/Nightly/classpath/install/lib
checking where Java core library headers are installed... 
/home/cpdev/Nightly/classpath/install/include
checking /home/cpdev/Nightly/classpath/install/include/jni.h usability... no
checking /home/cpdev/Nightly/classpath/install/include/jni.h presence... no
checking for /home/cpdev/Nightly/classpath/install/include/jni.h... no
configure: error: cannot find jni.h


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: ecj built with ecj on jamvm on Mon Apr 9 12:03:04 UTC 2007

2007-04-09 Thread cpdev
xargs: jamvm: No such file or directory


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: regressions for mauve-jamvm on Tue Apr 10 00:13:42 UTC 2007

2007-04-09 Thread cpdev
Baseline from: Mon Apr  9 17:14:00 UTC 2007

Regressions:
FAIL: java.lang.Thread.sleep

Totals:
PASS: 2915
XPASS: 0
FAIL: 193
XFAIL: 0


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


builder now runs Debian GNU/Linux 4.0 (etch)

2007-04-09 Thread Mark Wielaard
Hi,

To increase the release pressure a bit builder.classpath.org got
upgraded to the Debian Easter release. builder was running with some
backported packages and this was a good opportunity to refresh our
autobuilder and see whether anything broke. Happily Debian stable now
once again provides all the right versions of our dependencies.

Hint for our Debian lovers, for compiling the applet webplugin you will
need the libxul-dev package and dependencies. It will then be build
against xulrunner.

Fresh build logs should appear soon again on classpath-testresults.

Cheers,

Mark


signature.asc
Description: This is a digitally signed message part


[commit-cp] classpath ChangeLog javax/management/ObjectName...

2007-04-09 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Andrew John Hughes gnu_andrew 07/04/09 18:25:42

Modified files:
.  : ChangeLog 
javax/management: ObjectName.java 

Log message:
2007-04-07  Andrew John Hughes  [EMAIL PROTECTED]

* javax/management/ObjectName.java:
(propertyValuePattern): New cache variable.
(parse(String)): Record in propertyListPattern
not propertyPattern and set propertyValuePattern.
(isPropertyPattern()): Semantics altered to be the
OR of isPropertyListPattern() and isPropertyValuePattern().
(isPropertyListPattern()): Implemented.
(isPropertyValuePattern()): Implemented.
(isPropertyValuePattern(String)): Implemented.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.9227r2=1.9228
http://cvs.savannah.gnu.org/viewcvs/classpath/javax/management/ObjectName.java?cvsroot=classpathr1=1.14r2=1.15




[commit-cp] gjdoc ChangeLog src/gnu/classpath/tools/gjdoc/C...

2007-04-09 Thread Andrew John Hughes
CVSROOT:/sources/classpath
Module name:gjdoc
Changes by: Andrew John Hughes gnu_andrew 07/04/09 18:31:32

Modified files:
.  : ChangeLog 
src/gnu/classpath/tools/gjdoc: ClassDocImpl.java Parser.java 

Log message:
2007-04-09  Stephan Michels  [EMAIL PROTECTED]

* src/gnu/classpath/tools/gjdoc/ClassDocImpl.java,
* src/gnu/classpath/tools/gjdoc/Parser.java:
Add basic annotation support.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/gjdoc/ChangeLog?cvsroot=classpathr1=1.248r2=1.249
http://cvs.savannah.gnu.org/viewcvs/gjdoc/src/gnu/classpath/tools/gjdoc/ClassDocImpl.java?cvsroot=classpathr1=1.28r2=1.29
http://cvs.savannah.gnu.org/viewcvs/gjdoc/src/gnu/classpath/tools/gjdoc/Parser.java?cvsroot=classpathr1=1.25r2=1.26




[commit-cp] classpath native/jni/gtk-peer/gnu_java_awt_peer...

2007-04-09 Thread Francis Kung
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Francis Kung fkung07/04/09 21:34:28

Modified files:
native/jni/gtk-peer: gnu_java_awt_peer_gtk_ComponentGraphics.c 
include: gnu_java_awt_peer_gtk_ComponentGraphics.h 
gnu/java/awt/peer/gtk: ComponentGraphics.java 
.  : ChangeLog 

Log message:
2007-04-09  Francis Kung  [EMAIL PROTECTED]

PR 31311
* gnu/java/awt/peer/gtk/ComponentGraphics.java
(dispose): Removed method.
(disposeSurface): Removed method.
* gnu_java_awt_peer_gtk_ComponentGraphics.h: Regenerated.
* native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c
(Java_gnu_java_awt_peer_gtk_ComponentGraphics_disposeSurface): 
Removed.
(Java_gnu_java_awt_peer_gtk_ComponentGraphics_initState): 
Destroy surface
after it is used to create a cairo context.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/native/jni/gtk-peer/gnu_java_awt_peer_gtk_ComponentGraphics.c?cvsroot=classpathr1=1.18r2=1.19
http://cvs.savannah.gnu.org/viewcvs/classpath/include/gnu_java_awt_peer_gtk_ComponentGraphics.h?cvsroot=classpathr1=1.10r2=1.11
http://cvs.savannah.gnu.org/viewcvs/classpath/gnu/java/awt/peer/gtk/ComponentGraphics.java?cvsroot=classpathr1=1.27r2=1.28
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.9228r2=1.9229




[commit-cp] classpath ChangeLog javax/management/ObjectName...

2007-04-09 Thread Andrew John Hughes
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Andrew John Hughes gnu_andrew 07/04/09 22:35:04

Modified files:
.  : ChangeLog 
javax/management: ObjectName.java 

Log message:
2007-04-09  Andrew John Hughes  [EMAIL PROTECTED]

* javax/management/ObjectName.java:
(parse(String)): Catch multiple wildcards,
initialise with an empty string (so null isn't
appended), and emit comma even when wildcard
ends the list.
(checkComponents()): Catch newlines.
(quote(String)): Handle newlines and quotes
correctly.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.9229r2=1.9230
http://cvs.savannah.gnu.org/viewcvs/classpath/javax/management/ObjectName.java?cvsroot=classpathr1=1.15r2=1.16




[commit-cp] gjdoc ChangeLog src/gnu/classpath/tools/gjdoc/C...

2007-04-09 Thread Andrew John Hughes
CVSROOT:/sources/classpath
Module name:gjdoc
Changes by: Andrew John Hughes gnu_andrew 07/04/09 23:47:56

Modified files:
.  : ChangeLog 
src/gnu/classpath/tools/gjdoc: ClassDocImpl.java Parser.java 

Log message:
2007-04-10  Andrew John Hughes  [EMAIL PROTECTED]

* src/gnu/classpath/tools/gjdoc/ClassDocImpl.java:
Add enumeration support and allow whitespace in
type variables.
* src/gnu/classpath/tools/gjdoc/Parser.java:
Add commented-out line for printing file being
processed.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/gjdoc/ChangeLog?cvsroot=classpathr1=1.249r2=1.250
http://cvs.savannah.gnu.org/viewcvs/gjdoc/src/gnu/classpath/tools/gjdoc/ClassDocImpl.java?cvsroot=classpathr1=1.29r2=1.30
http://cvs.savannah.gnu.org/viewcvs/gjdoc/src/gnu/classpath/tools/gjdoc/Parser.java?cvsroot=classpathr1=1.26r2=1.27